==> ACE%2BTAO-5.7.2.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_null_return_value.h <==
//
// $Id: be_visitor_null_return_value.h 86020 2009-07-14 12:13:54Z wotte $
//
/* -*- c++ -*- */
// ============================================================================
//
// = LIBRARY
//    TAO_IDL_BE
//
// = FILENAME
//    be_visitor_null_return_value.h
//
// = DESCRIPTION
//    Encapsulation of rules for generating null return values
//
// = AUTHOR
//    Jeff Parsons
//
// ============================================================================

#ifndef BE_VISITOR_NULL_RETURN_VALUE_H
#define BE_VISITOR_NULL_RETURN_VALUE_H

#include "be_visitor_decl.h"

class TAO_OutStream;

class be_visitor_null_return_value : public be_visitor_decl
{
  //
  // = TITLE
  //   be_visitor_null_return_value
  //
  // = DESCRIPTION
  //   Contains overloaded methods that generate null return
  //   values, compliant with the CORBA IDL C++ mapping, and
  //   portable to all platforms supported by ACE.
  //
  //
public:
  be_visitor_null_return_value (be_visitor_context *ctx);
  virtual ~be_visitor_null_return_value (void);
  
  virtual int visit_array (be_array *);
  virtual int visit_component (be_component *);
  virtual int visit_enum (be_enum *);
  virtual int visit_eventtype (be_eventtype *);
  virtual int visit_home (be_home *);
  virtual int visit_interface (be_interface *);
  virtual int visit_predefined_type (be_predefined_type *);
  virtual int visit_sequence (be_sequence *);
  virtual int visit_string (be_string *);
  virtual int visit_structure (be_structure *);
  virtual int visit_typedef (be_typedef *);
  virtual int visit_union (be_union *);
  virtual int visit_valuebox (be_valuebox *);
  virtual int visit_valuetype (be_valuetype *);
  
protected:
  TAO_OutStream & os_;
};

#endif /* BE_VISITOR_NULL_RETURN_VALUE_H */

==> ACE%2BTAO-6.2.3.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_null_return_value.h <==
/* -*- c++ -*- */
//=============================================================================
/**
 *  @file    be_visitor_null_return_value.h
 *
 *  $Id: be_visitor_null_return_value.h 91742 2010-09-13 18:23:17Z johnnyw $
 *
 *  Encapsulation of rules for generating null return values
 *
 *
 *  @author Jeff Parsons
 */
//=============================================================================


#ifndef BE_VISITOR_NULL_RETURN_VALUE_H
#define BE_VISITOR_NULL_RETURN_VALUE_H

#include "be_visitor_decl.h"

class TAO_OutStream;

/**
 * @class be_visitor_null_return_value
 *
 * @brief be_visitor_null_return_value
 *
 * Contains overloaded methods that generate null return
 * values, compliant with the CORBA IDL C++ mapping, and
 * portable to all platforms supported by ACE.
 */
class be_visitor_null_return_value : public be_visitor_decl
{
public:
  be_visitor_null_return_value (be_visitor_context *ctx);
  virtual ~be_visitor_null_return_value (void);

  virtual int visit_array (be_array *);
  virtual int visit_component (be_component *);
  virtual int visit_enum (be_enum *);
  virtual int visit_eventtype (be_eventtype *);
  virtual int visit_home (be_home *);
  virtual int visit_interface (be_interface *);
  virtual int visit_predefined_type (be_predefined_type *);
  virtual int visit_sequence (be_sequence *);
  virtual int visit_string (be_string *);
  virtual int visit_structure (be_structure *);
  virtual int visit_typedef (be_typedef *);
  virtual int visit_union (be_union *);
  virtual int visit_valuebox (be_valuebox *);
  virtual int visit_valuetype (be_valuetype *);

protected:
  TAO_OutStream & os_;
};

#endif /* BE_VISITOR_NULL_RETURN_VALUE_H */
